Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1553)

Unified Diff: runtime/vm/scopes.cc

Issue 14925005: Remove stack_frame_<arch>.cc files. (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 7 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/parser.cc ('k') | runtime/vm/stack_frame.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/scopes.cc
===================================================================
--- runtime/vm/scopes.cc (revision 22469)
+++ runtime/vm/scopes.cc (working copy)
@@ -569,15 +569,15 @@
int LocalVariable::BitIndexIn(intptr_t fixed_parameter_count) const {
ASSERT(!is_captured());
// Parameters have positive indexes with the lowest index being
// kLastParamSlotIndex. Locals and copied parameters have negative indexes
// with the lowest (closest to zero) index being kFirstLocalSlotIndex.
if (index() > 0) {
// Shift non-negative indexes so that the lowest one is 0.
- return (fixed_parameter_count - 1) - (index() - kLastParamSlotIndex);
+ return fixed_parameter_count - (index() - kParamEndSlotFromFp);
} else {
// Shift negative indexes so that the lowest one is 0 (they are still
// non-positive).
- return fixed_parameter_count - (index() - kFirstLocalSlotIndex);
+ return fixed_parameter_count - (index() - kFirstLocalSlotFromFp);
}
}
« no previous file with comments | « runtime/vm/parser.cc ('k') | runtime/vm/stack_frame.h » ('j') | no next file with comments »
@@ -569,15 +569,15 @@
ASSERT(!is_captured());
// Parameters have positive indexes with the lowest index being
- // kLastParamSlotIndex. Locals and copied parameters have negative indexes
- // with the lowest (closest to zero) index being kFirstLocalSlotIndex.
+ // kParamEndSlotFromFp + 1. Locals and copied parameters have negative
+ // indexes with the lowest (closest to 0) index being kFirstLocalSlotFromFp.
if (index() > 0) {
// Shift non-negative indexes so that the lowest one is 0.

Powered by Google App Engine
This is Rietveld 408576698